@@ -9,11 +9,11 @@ if TYPE_CHECKING:
     from pointcloudset import PointCloud
 
 
-def from_open3d(open3d_data: o3d.open3d_pybind.geometry.PointCloud) -> dict:
+def from_open3d(open3d_data: o3d.geometry.PointCloud) -> dict:
     """Converts a open3d pointcloud to a PointCloud.
 
     Args:
-        open3d_data (open3d.open3d_pybind.geometry.PointCloud): Open3D pointcloud which should be converted.
+        open3d_data (o3d.cpu.pybind.geometry.PointCloud): Open3D pointcloud which should be converted.
 
     Returns:
         dict: Pointcloud data.
@@ -22,14 +22,14 @@ def from_open3d(open3d_data: o3d.open3d_pybind.geometry.PointCloud) -> dict:
     return {"data": pyntcloud_data.points}
 
 
-def to_open3d(pointcloud: PointCloud) -> o3d.open3d_pybind.geometry.PointCloud:
+def to_open3d(pointcloud: PointCloud) -> o3d.geometry.PointCloud:
     """Converts PointCloud to open3d PointCloud.
 
     Args:
         df (pd.DataFrame): Pointcloud dataframe with x,y,z,intensity.
 
     Returns:
-        open3d.open3d_pybind.geometry.PointCloud: Open3d pointcloud object.
+        o3d.cpu.pybind.geometry.PointCloud: Open3d pointcloud object.
     """
     pcd = o3d.geometry.PointCloud()
     pcd.points = o3d.utility.Vector3dVector(pointcloud.points.xyz)
